@@ -68,7 +68,7 @@ sscox <- function(formula,type=NULL,data=list(),weights=NULL,subset,
     term$labels <- term$labels[term$labels!="1"]
     ## Generate random
     if (!is.null(random)) {
-        if (class(random)=="formula") random <- mkran(random,data)
+        if (inherits(random,"formula")) random <- mkran(random,data)
         random$qd.z <- random$z
         random$z <- random$z[yy$status,]
     }
@@ -189,7 +189,7 @@ sspcox <- function(s,r,q,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha,random,bias)
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk0), as.integer(nxiz),
                         as.double(t(cbind(r.wk,s))), as.integer(nobs),
-                        as.integer(sum(cnt)), as.integer(cnt),
+                        as.double(sum(cnt)), as.double(cnt),
                         as.double(cbind(qd.r.wk,qd.s)), as.integer(nqd),
                         as.integer(bias$nt), as.double(bias$wt),
                         as.double(t(qd.wt*bias$qd.wt)),
@@ -278,12 +278,14 @@ sspcox <- function(s,r,q,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha,random,bias)
         cv <- (zz$min-cv.shift)/cv.scale
     }
     else {
+        mn0 <- log.la0-6
+        mx0 <- log.la0+6
         repeat {
-            mn <- la-1
-            mx <- la+1
-            if (mx>log.la0+6) break
+            mn <- max(la-1,mn0)
+            mx <- min(la+1,mx0)
             zz <- nlm0(cv,c(mn,mx))
-            if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+            if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+                (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
             else la <- zz$est
         }
         cv <- zz$min
@@ -377,7 +379,7 @@ mspcox <- function(s,r,id.basis,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha,random,bi
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk0), as.integer(nxiz),
                         as.double(t(cbind(r.wk0,s))), as.integer(nobs),
-                        as.integer(sum(cnt)), as.integer(cnt),
+                        as.double(sum(cnt)), as.double(cnt),
                         as.double(cbind(qd.r.wk0,qd.s)), as.integer(nqd),
                         as.integer(bias$nt), as.double(bias$wt),
                         as.double(t(qd.wt*bias$qd.wt)),
