@@ -84,7 +84,7 @@ sshzd <- function(formula,type=NULL,data=list(),alpha=1.4,
     term <- mkterm(mf,type)
     ## Generate random
     if (!is.null(random)) {
-        if (class(random)=="formula") random <- mkran(random,data)
+        if (inherits(random,"formula")) random <- mkran(random,data)
     }
     ## Generate Gauss-Legendre quadrature
     nmesh <- 200
@@ -284,7 +284,7 @@ msphzd <- function(s,r,id.wk,Nobs,cnt,qd.s,qd.r,qd.wt,random,prec,maxiter,alpha,
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk0), as.integer(nxiz),
                         as.double(t(cbind(r.wk,s))), as.integer(nT),
-                        as.integer(Nobs), as.integer(sum(cnt)), as.integer(cnt),
+                        as.integer(Nobs), as.double(sum(cnt)), as.double(cnt),
                         as.double(qd.r.wk), as.integer(nqd),
                         as.double(qd.wt), as.integer(nx),
                         as.double(prec), as.integer(maxiter),
@@ -345,7 +345,7 @@ msphzd <- function(s,r,id.wk,Nobs,cnt,qd.s,qd.r,qd.wt,random,prec,maxiter,alpha,
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk0), as.integer(nxiz),
                         as.double(t(cbind(r.wk0,s))), as.integer(nT),
-                        as.integer(Nobs), as.integer(sum(cnt)), as.integer(cnt),
+                        as.integer(Nobs), as.double(sum(cnt)), as.double(cnt),
                         as.double(qd.r.wk0), as.integer(nqd),
                         as.double(qd.wt), as.integer(nx),
                         as.double(prec), as.integer(maxiter),
