@@ -88,7 +88,7 @@ sshzd1 <- function(formula,type=NULL,data=list(),alpha=1.4,
     term <- mkterm(mf,type)
     ## Generate random
     if (!is.null(random)) {
-        if (class(random)=="formula") random <- mkran(random,data)
+        if (inherits(random,"formula")) random <- mkran(random,data)
     }
     ## Generate Gauss-Legendre quadrature
     nmesh <- 200
@@ -300,8 +300,8 @@ msphzd1 <- function(s,r,id.wk,Nobs,cnt,int.s,int.r,rho,random,prec,maxiter,alpha
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk0), as.integer(nxiz),
                         as.double(cbind(r.wk,s)), as.integer(nT),
-                        as.integer(Nobs), as.integer(sum(cnt)),
-                        as.integer(cnt),
+                        as.integer(Nobs), as.double(sum(cnt)),
+                        as.double(cnt),
                         as.double(c(int.r.wk,int.s)), as.double(rho),
                         as.double(prec), as.integer(maxiter),
                         as.double(.Machine$double.eps), integer(nn),
@@ -352,8 +352,8 @@ msphzd1 <- function(s,r,id.wk,Nobs,cnt,int.s,int.r,rho,random,prec,maxiter,alpha
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk0), as.integer(nxiz),
                         as.double(cbind(r.wk0,s)), as.integer(nT),
-                        as.integer(Nobs), as.integer(sum(cnt)),
-                        as.integer(cnt),
+                        as.integer(Nobs), as.double(sum(cnt)),
+                        as.double(cnt),
                         as.double(c(int.r.wk0,int.s)), as.double(rho),
                         as.double(prec), as.integer(maxiter),
                         as.double(.Machine$double.eps), integer(nn),
